from PyQt4 import QtGui, QtCore


class SplashScreen(QtGui.QSplashScreen):
    def __init__(self, pixmap, font_size=None):
        QtGui.QSplashScreen.__init__(self)
        self._pixmap = pixmap
        self._color = QtCore.Qt.black
        self._message = QtCore.QString()
        self._alignment = QtCore.Qt.AlignLeft
        self.setWindowFlags(QtCore.Qt.FramelessWindowHint |
                            QtCore.Qt.WindowStaysOnTopHint)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
        self.setFixedSize(self._pixmap.size())
        font = QtGui.QFont(self.font())
        font_size = font_size or (font.pointSize() + 10)
        font.setPointSize(font_size)
        font.setBold(True)
        self.setFont(font)
        self.setMask(self._pixmap.mask())
        self.move(QtCore.QPoint(100,100))

    def clearMessage(self):
        self._message.clear()
        self.repaint()

    def showMessage(self, message, alignment=QtCore.Qt.AlignCenter,
                                   color=QtCore.Qt.blue):
        self._message = QtCore.QString(message)
        self._alignment = alignment
        self._color = color
        self.repaint()

    def paintEvent(self, event):
        textbox = QtCore.QRect(self.rect())
        textbox.setRect(textbox.x() + 5, textbox.y() + 5,
                        textbox.width() - 10, textbox.height() - 10)
        painter = QtGui.QPainter(self)
        painter.drawPixmap(self.rect(), self._pixmap)
        painter.setPen(QtGui.QColor(self._color))
        painter.drawText(textbox, self._alignment, self._message)

    def mousePressEvent(self, event):
        self.hide()


class SimpleSplashScreen(QtGui.QWidget):
    def __init__(self, pixmap, font_size=None):
        QtGui.QWidget.__init__(self)
        self._pixmap = pixmap
        self._color = QtCore.Qt.black
        self._message = QtCore.QString()
        self._alignment = QtCore.Qt.AlignLeft
        self.setWindowFlags(QtCore.Qt.FramelessWindowHint |
                            QtCore.Qt.WindowStaysOnTopHint)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
        self.setFixedSize(self._pixmap.size())
        font = QtGui.QFont(self.font())
        font_size = font_size or (font.pointSize() + 10)
        font.setPointSize(font_size)
        font.setBold(True)
        self.setFont(font)
        self.setMask(self._pixmap.mask())
        self.move(QtCore.QPoint(100,100))

    def clearMessage(self):
        self._message.clear()
        self.repaint()

    def showMessage(self, message, alignment=QtCore.Qt.AlignCenter,
                                   color=QtCore.Qt.blue):
        self._message = QtCore.QString(message)
        self._alignment = alignment
        self._color = color
        self.repaint()

    def paintEvent(self, event):
        textbox = QtCore.QRect(self.rect())
        textbox.setRect(textbox.x() + 5, textbox.y() + 5,
                        textbox.width() - 10, textbox.height() - 10)
        painter = QtGui.QPainter(self)
        painter.drawPixmap(self.rect(), self._pixmap)
        painter.setPen(QtGui.QColor(self._color))
        painter.drawText(textbox, self._alignment, self._message)

    def mousePressEvent(self, event):
        self.hide()

def show_splash(path):
    image = QtGui.QPixmap(path)
    splash = SplashScreen(image)
    splash.show()
    QtGui.QApplication.processEvents()
    for count in range(1, 6):
        splash.showMessage(splash.tr('Processing %1...').arg(count))
        QtGui.QApplication.processEvents()
        QtCore.QThread.msleep(1000)
    splash.hide()
    splash.close()

if __name__ == '__main__':

    import sys
    app = QtGui.QApplication(sys.argv)
    screen_res = app.desktop().screenGeometry()
    screen_center = QtCore.QPoint(screen_res.width()/2,
                                  screen_res.height()/2)
    show_splash(sys.argv[1])
    app.quit()

